Response class

Represents a response object with various properties such as status, message, data, body, and request.

Available extensions

Constructors

Response({bool status = false, String? message, dynamic data, dynamic body, Request? request})
Constructs a Response object with optional properties.

Properties

body → dynamic
Represents the body of the response, can hold any type of data.
final
data → dynamic
Holds any data returned by the response.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
An optional message providing additional information about the response.
final
request → Request?
The original request that resulted in this response.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
Indicates the status of the response.
final

Methods

check(String path, {bool deep = false}) → void

Available on Response, provided by the ApiTestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the object to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited